#
# spec file for package liborcus
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname liborcus-0_11-0
Name:           liborcus
Version:        0.11.0
Release:        5.1
Summary:        Spreadsheet file processing library
License:        MIT
Group:          Productivity/Publishing/Word
Url:            https://gitlab.com/orcus/orcus/
Source:         http://kohei.us/files/orcus/src/%{name}-%{version}.tar.xz
BuildRequires:  boost-devel
BuildRequires:  coreutils
BuildRequires:  gcc-c++
BuildRequires:  libstdc++-devel
BuildRequires:  pkg-config
BuildRequires:  python-xml
BuildRequires:  pkgconfig(libixion-0.11)
BuildRequires:  pkgconfig(mdds-1.0)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%package -n %{libname}
Summary:        Spreadsheet file processing library
Group:          System/Libraries
# Same version, soname updated -> same file -> conflict
Conflicts:      liborcus-0_10-0

%description -n %{libname}
Standalone file import filter library for spreadsheet documents. Currently
under development are ODS, XLSX and CSV import filters.

%description
Standalone file import filter library for spreadsheet documents. Currently
under development are ODS, XLSX and CSV import filters.

%package devel
Summary:        Spreadsheet file processing library
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       pkgconfig(zlib)

%description devel
Standalone file import filter library for spreadsheet documents. Currently
under development are ODS, XLSX and CSV import filters.

%package tools
Summary:        Spreadsheet file processing library
Group:          Productivity/Publishing/Word
Requires:       %{libname} = %{version}

%description tools
Tools to work with various xml streams.

%package python3
Summary:        Python bindings for libixion
Group:          Productivity/Publishing/Word

%description python3
Python 3 bindings for %{name}.

%prep
%setup -q

%build
%configure \
	--disable-silent-rules \
	--disable-static \
	--disable-debug \
	--disable-werror \
	--docdir=%{_docdir}/%{name}
make %{?_smp_mflags}

%check
make check %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files tools
%defattr(-,root,root)
%{_bindir}/*

%files python3
%defattr(-,root,root)
%dir %{python3_sitelib}/orcus/
%{python3_sitelib}/orcus/__init__.py
%{python3_sitelib}/orcus/json.py
%{python3_sitearch}/_orcus.so
%{python3_sitearch}/_orcus_json.so

%changelog
* Thu May  5 2016 tchvatal@suse.com
- Coflict with liborcus-0_10-0
* Tue Mar  8 2016 fstrba@suse.com
- Change package name to correspond to the soname  of the
  libraries provided.
* Mon Mar  7 2016 tchvatal@suse.com
- Version update to 0.11.0:
  * Use mdds 1.0
  * Use ixion 0.11
  * Use python3 instead of python2
* Mon Dec 21 2015 tchvatal@suse.com
- Version update to 0.9.2:
  * Various bugfixes and update for libreoffice 5.1
* Tue Mar 24 2015 tchvatal@suse.com
- Version bump to 0.7.1:
  * Various boost bugfixes and update for new ixion
- Obsoleted patch:
  * liborcus-boost-1.56.patch
* Mon Oct 27 2014 dmitry_r@opensuse.org
- Fix build with boost-1.56
  * liborcus-boost-1.56.patch
* Mon May 26 2014 fstrba@suse.com
- Upgrade to upstream version 0.7.0
- Remove unneeded upstreamed patches:
  * liborcus-more-lib64.patch
  * liborcus-0.5.1-linking.patch
  * liborcus-0.5.1-mdds.patch
  * liborcus-0.5.1-oldnamespace.patch
- Use pkgconfig BuildRequires wherever it is possible
* Sat Jan 25 2014 tchvatal@suse.com
- Clean with spec-cleaner and Verbosify the output.
* Mon Jan  6 2014 matz@suse.com
- Add aarch64 and ppc64le to list of 64bit archs for boost_system
  detection.
  Added patches:
  * liborcus-more-lib64.patch
* Tue Nov 12 2013 jengelh@inai.de
- Correct description not to mention an N-gram text categorizer
* Thu Aug  1 2013 tchvatal@suse.com
- Version bump to 0.5.1:
  * More fixes around streaming
  * Various boost fixes
  * Improvements required for libreoffice-4.1.
- Use full download url for tarball
- Drop libzip-devel requirement
- Add patch for new mdds liborcus-0.5.1-mdds.patch
- Add patch for SLE11 gcc liborcus-0.5.1-oldnamespace.patch
- Add patch for newest boost liborcus-0.5.1-linking.patch
- Drop deprecated patch boost-configure.patch
* Sun Jun 16 2013 schwab@suse.de
- boost-configure.patch: fix boost configure check
* Fri May 31 2013 tchvatal@suse.com
- Fix building with boost-1.52 and newer.
* Wed Feb  6 2013 pmladek@suse.com
- Add libzip-devel and zlib-devel into Requires of the devel package;
  they are needed for linking against liborcus
* Tue Jan  8 2013 tchvatal@suse.com
- Rename package and sort it out for acceptance to factory.
* Tue Dec 18 2012 tchvatal@suse.com
- Build gnumeric filters as libreoffice check for them.
  * cleanup the spec a bit.
* Wed Nov 28 2012 kyoshida@suse.com
- Official 0.3.0 package.
* Sat Nov 10 2012 kyoshida@suse.com
- Updated snapshot from the latest master branch.
* Fri Oct  5 2012 kyoshida@suse.com
- Latest development snapshot from the master branch.
* Tue Oct  2 2012 kyoshida@suse.com
- Latest development snapshot from the master branch.
* Wed Sep 26 2012 kyoshida@suse.com
- Remove the obsolete package and spec.
* Wed Sep 26 2012 kyoshida@suse.com
- Add new package and spec from the latest master branch.
* Thu Sep  6 2012 kyoshida@suse.com
- Updated the package with all sorts of fixes.
* Thu Aug 30 2012 kyoshida@suse.com
- Updated the package.  It now supports --disable-libzip.
* Tue Jul 31 2012 kyoshida@suse.com
- Modified spec file to keep rpmlint happy.
* Tue Jul 31 2012 kyoshida@suse.com
- Added initial spec file.
